==> gozerbot_0.99.1.orig.tar.gz: gozerbot-0.99.1/gplugs/shakespear.py <==
# plugs/shakespear.py
#
#

""" uses the random lib """

__copyright__ = 'this file is in the public domain'
__revision__ = '$Id: shakespeare.py 517 2006-12-21 05:00:00Z deck $'

from gozerbot.generic import handle_exception
from gozerbot.commands import cmnds
from gozerbot.examples import examples
from gozerbot.plughelp import plughelp
from gozerbot.tests import tests

import re, random

plughelp.add('shakespear', 'display a shakespearean insult')

set_a=["Away I say",
       "Bathe thyself",
       "Be not deaf",
       "Behold thy mirror",
       "Beware my sting",
       "Clean thine ears",
       "Drink up eisel",
       "Eat a crododile",
       "Eat my knickers",
       "Fie upon thee",
       "Forsooth say I",
       "Get thee gone",
       "Get thee hence",
       "Grow unsightly warts",
       "Hear me now",
       "Hear this pox alert",
       "I'll see thee hang'd",
       "Kiss my codpiece",
       "Lead apes in hell",
       "Methinks you stinks",
       "My finger in thine eye",
       ">>Phui<< I say",
       "Remove thine ass hence",
       "Resign not thy day gig",
       "Sit thee on a spit",
       "Sorrow on thee",
       "Swim with leeches",
       "Thou dost intrude",
       "Thy mother wears armor",
       "Trip on thy sword",
       "Tune thy lute",
       "Why, how now putz",
       "Wipe thy ugly face"]
set_b=["artless",
       "bawdy",
       "beslubbering",
       "bootless",
       "cankerous",
       "churlish",
       "cockered",
       "clouted",
       "craven",
       "currish",
       "dankish",
       "dissembling",
       "droning",
       "errant",
       "fawning",
       "fobbing",
       "fool-born",
       "froward",
       "frothy",
       "gleeking",
       "goatish",
       "gorbellied",
       "ill-nurtured",
       "impertinent",
       "incestuous",
       "incurable",
       "infectious",
       "jarring",
       "loggerheaded",
       "lumpish",
       "loutish",
       "mammering",
       "mangled",
       "mewling",
       "paunchy",
       "pribbling",
       "puking",
       "puny",
       "qualling",
       "rank",
       "reeky",
       "roguish",
       "rump-fed",
       "ruttish",
       "saucy",
       "spleeny",
       "spongy",
       "surly",
       "tardy-gaited",
       "tottering",
       "unmuzzled",
       "vain",
       "venomed",
       "warped",
       "wayward",
       "weedy",
       "whoreson",
       "wretched",
       "yeasty"]
set_c=["addlepated",
       "base-court",
       "bat-fowling",
       "beef-witted",
       "beetle-headed",
       "boil-brained",
       "clapper-clawed",
       "clay-brained",
       "codpiece-sniffing",
       "common-kissing",
       "crook-pated",
       "dismal-dreaming",
       "dizzy-eyed",
       "doghearted",
       "dread-bolted",
       "earth-vexing",
       "elf-skinned",
       "fat-kidneyed",
       "fen-sucked",
       "flap-mouthed",
       "fly-bitten",
       "folly-fallen",
       "fool-born",
       "foul-practicing",
       "full-gorged",
       "guts-griping",
       "half-faced",
       "hasty-witted",
       "hedge-born",
       "hell-hated",
       "idle-headed",
       "ill-breeding",
       "ill-nurtured",
       "knotty-pated",
       "mad-brained",
       "milk-livered",
       "motley-minded",
       "onion-eyed",
       "plume-plucked",
       "pottle-deep",
       "pox-marked",
       "reeling-ripe",
       "rough-hewn",
       "rude-growing",
       "rump-fed",
       "shard-borne",
       "sheep-biting",
       "spur-galled",
       "swag-bellied",
       "tardy-gaited",
       "tickle-brained",
       "toad-spotted",
       "unchin-snouted",
       "weather-bitten"]
set_d=["apple-john",
       "baggage",
       "barnacle",
       "bladder",
       "boar-pig",
       "bugbear",
       "bum-bailey",
       "canker-blossom",
       "clack-dish",
       "clotpole",
       "coxcomb",
       "codpiece",
       "death-token",
       "dewberry",
       "dotard",
       "flap-dragon",
       "flax-wench",
       "flea",
       "flirt-gill",
       "foot-licker",
       "fustilarian",
       "giglet",
       "gudgeon",
       "haggard",
       "harpy",
       "hedge-pig",
       "horn-beast",
       "hugger-mugger",
       "jolthead",
       "knave",
       "lewdster",
       "lout",
       "maggot-pie",
       "malt-worm",
       "mammet",
       "measle",
       "minnow",
       "miscreant",
       "moldwarp",
       "mumble-news",
       "nit",
       "nut-hook",
       "pigeon-egg",
       "pignut",
       "pumpion",
       "puttock",
       "ratsbane",
       "rudesby",
       "scut",
       "skainsmate",
       "strumpet",
       "varlot",
       "vassal",
       "wagtail",
       "water-fly",
       "whey-face",
       "winter-cricket"]

def handle_insult(bot, ievent):
    ievent.reply(random.choice(set_a)+" "+random.choice(set_b)+" "+random.choice(set_c)+" "+random.choice(set_d))
    
cmnds.add('insult', handle_insult, 'USER')
examples.add('insult', 'show a shakespearean insult', 'insult')
tests.add('insult')

==> gozerbot-1.0.3.tar.gz: gozerbot-1.0.3/gplugs/shakespear.py <==
# plugs/shakespear.py
#
#

""" brabble some shakepsear .. uses the random lib """

__status__ = "seen"

## gozerbot imports

from gozerbot.generic import handle_exception
from gozerbot.commands import cmnds
from gozerbot.examples import examples
from gozerbot.plughelp import plughelp
from gozerbot.tests import tests

## basic imports

import re
import random

## plughelp

plughelp.add('shakespear', 'display a shakespearean insult')

## defines

set_a=["Away I say",
       "Bathe thyself",
       "Be not deaf",
       "Behold thy mirror",
       "Beware my sting",
       "Clean thine ears",
       "Drink up eisel",
       "Eat a crododile",
       "Eat my knickers",
       "Fie upon thee",
       "Forsooth say I",
       "Get thee gone",
       "Get thee hence",
       "Grow unsightly warts",
       "Hear me now",
       "Hear this pox alert",
       "I'll see thee hang'd",
       "Kiss my codpiece",
       "Lead apes in hell",
       "Methinks you stinks",
       "My finger in thine eye",
       ">>Phui<< I say",
       "Remove thine ass hence",
       "Resign not thy day gig",
       "Sit thee on a spit",
       "Sorrow on thee",
       "Swim with leeches",
       "Thou dost intrude",
       "Thy mother wears armor",
       "Trip on thy sword",
       "Tune thy lute",
       "Why, how now putz",
       "Wipe thy ugly face"]
set_b=["artless",
       "bawdy",
       "beslubbering",
       "bootless",
       "cankerous",
       "churlish",
       "cockered",
       "clouted",
       "craven",
       "currish",
       "dankish",
       "dissembling",
       "droning",
       "errant",
       "fawning",
       "fobbing",
       "fool-born",
       "froward",
       "frothy",
       "gleeking",
       "goatish",
       "gorbellied",
       "ill-nurtured",
       "impertinent",
       "incestuous",
       "incurable",
       "infectious",
       "jarring",
       "loggerheaded",
       "lumpish",
       "loutish",
       "mammering",
       "mangled",
       "mewling",
       "paunchy",
       "pribbling",
       "puking",
       "puny",
       "qualling",
       "rank",
       "reeky",
       "roguish",
       "rump-fed",
       "ruttish",
       "saucy",
       "spleeny",
       "spongy",
       "surly",
       "tardy-gaited",
       "tottering",
       "unmuzzled",
       "vain",
       "venomed",
       "warped",
       "wayward",
       "weedy",
       "whoreson",
       "wretched",
       "yeasty"]
set_c=["addlepated",
       "base-court",
       "bat-fowling",
       "beef-witted",
       "beetle-headed",
       "boil-brained",
       "clapper-clawed",
       "clay-brained",
       "codpiece-sniffing",
       "common-kissing",
       "crook-pated",
       "dismal-dreaming",
       "dizzy-eyed",
       "doghearted",
       "dread-bolted",
       "earth-vexing",
       "elf-skinned",
       "fat-kidneyed",
       "fen-sucked",
       "flap-mouthed",
       "fly-bitten",
       "folly-fallen",
       "fool-born",
       "foul-practicing",
       "full-gorged",
       "guts-griping",
       "half-faced",
       "hasty-witted",
       "hedge-born",
       "hell-hated",
       "idle-headed",
       "ill-breeding",
       "ill-nurtured",
       "knotty-pated",
       "mad-brained",
       "milk-livered",
       "motley-minded",
       "onion-eyed",
       "plume-plucked",
       "pottle-deep",
       "pox-marked",
       "reeling-ripe",
       "rough-hewn",
       "rude-growing",
       "rump-fed",
       "shard-borne",
       "sheep-biting",
       "spur-galled",
       "swag-bellied",
       "tardy-gaited",
       "tickle-brained",
       "toad-spotted",
       "unchin-snouted",
       "weather-bitten"]
set_d=["apple-john",
       "baggage",
       "barnacle",
       "bladder",
       "boar-pig",
       "bugbear",
       "bum-bailey",
       "canker-blossom",
       "clack-dish",
       "clotpole",
       "coxcomb",
       "codpiece",
       "death-token",
       "dewberry",
       "dotard",
       "flap-dragon",
       "flax-wench",
       "flea",
       "flirt-gill",
       "foot-licker",
       "fustilarian",
       "giglet",
       "gudgeon",
       "haggard",
       "harpy",
       "hedge-pig",
       "horn-beast",
       "hugger-mugger",
       "jolthead",
       "knave",
       "lewdster",
       "lout",
       "maggot-pie",
       "malt-worm",
       "mammet",
       "measle",
       "minnow",
       "miscreant",
       "moldwarp",
       "mumble-news",
       "nit",
       "nut-hook",
       "pigeon-egg",
       "pignut",
       "pumpion",
       "puttock",
       "ratsbane",
       "rudesby",
       "scut",
       "skainsmate",
       "strumpet",
       "varlot",
       "vassal",
       "wagtail",
       "water-fly",
       "whey-face",
       "winter-cricket"]

## insult command

def handle_insult(bot, ievent):
    ievent.reply(random.choice(set_a)+" "+random.choice(set_b)+" "+random.choice(set_c)+" "+random.choice(set_d))
    
cmnds.add('insult', handle_insult, 'USER')
examples.add('insult', 'show a shakespearean insult', 'insult')
tests.add('insult')

#### BHJTW 23-01-2012
